@@ -46,7 +46,12 @@ class ChromiumDriver(RemoteWebDriver):
         """
         self.service = service
 
-        self.service.path = DriverFinder.get_path(self.service, options)
+        finder = DriverFinder(self.service, options)
+        if finder.get_browser_path():
+            options.binary_location = finder.get_browser_path()
+            options.browser_version = None
+
+        self.service.path = finder.get_driver_path()
         self.service.start()
 
         executor = ChromiumRemoteConnection(
