@@ -93,7 +93,7 @@ class WebElement(BaseWebElement):
         """Clicks the element."""
         self._execute(Command.CLICK_ELEMENT)
 
-    def submit(self):
+    def submit(self) -> None:
         """Submits a form."""
         script = (
             "/* submitForm */var form = arguments[0];\n"
@@ -191,7 +191,7 @@ class WebElement(BaseWebElement):
         """Returns whether the element is enabled."""
         return self._execute(Command.IS_ELEMENT_ENABLED)["value"]
 
-    def send_keys(self, *value) -> None:
+    def send_keys(self, *value: str) -> None:
         """Simulates typing into the element.
 
         :Args:
